@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
 our $DATE = '2014-11-20'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $VERSION = '0.51'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -453,12 +453,16 @@ sub run_help {
         if ($has_sc_no_sc) {
             $res = Perinci::Sub::To::CLIOptSpec::gen_cli_opt_spec_from_meta(
                 meta => {v=>1.1}, meta_is_normalized => 1,
-                common_opts => $self->common_opts,
+                common_opts  => $self->common_opts,
+                per_arg_json => $self->per_arg_json,
+                per_arg_yaml => $self->per_arg_yaml,
             );
         } else {
             $res = Perinci::Sub::To::CLIOptSpec::gen_cli_opt_spec_from_meta(
                 meta => $meta, meta_is_normalized => 1,
-                common_opts => $self->common_opts,
+                common_opts  => $self->common_opts,
+                per_arg_json => $self->per_arg_json,
+                per_arg_yaml => $self->per_arg_yaml,
             );
         }
         die [500, "gen_cli_opt_spec_from_meta failed: ".
@@ -482,6 +486,8 @@ sub run_help {
 
     # options
     {
+        require Data::Dmp;
+
         my $opts = $cliospec->{opts};
         last unless keys %$opts;
 
@@ -504,8 +510,29 @@ sub run_help {
             push @help, "\n$cat:\n";
             for my $opt (@opts) {
                 my $ospec = $opts->{$opt};
-                push @help, sprintf("  %-${len}s  %s\n",
-                                    $opt, $ospec->{summary}//'');
+                my $arg_spec = $ospec->{arg_spec};
+                my $is_bool = $arg_spec->{schema} &&
+                    $arg_spec->{schema}[0] eq 'bool';
+                my $show_default = exists($ospec->{default}) &&
+                    !$is_bool && !$ospec->{is_base64} &&
+                        !$ospec->{is_json} && !$ospec->{is_yaml};
+                my $add_sum = '';
+                if ($ospec->{is_base64}) {
+                    $add_sum = " (base64-encoded)";
+                } elsif ($ospec->{is_json}) {
+                    $add_sum = " (JSON-encoded)";
+                } elsif ($ospec->{is_yaml}) {
+                    $add_sum = " (YAML-encoded)";
+                }
+                push @help, sprintf(
+                    "  %-${len}s  %s%s%s\n",
+                    $opt,
+                    $ospec->{summary}//'',
+                    $add_sum,
+                    ($show_default ?
+                         " [".Data::Dmp::dmp($ospec->{default})."]":""),
+
+                );
             }
         }
     }
@@ -544,7 +571,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.50 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-11-20.
+This document describes version 0.51 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-11-20.
 
 =head1 SYNOPSIS
 
@@ -719,7 +746,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
